summaryrefslogtreecommitdiff
path: root/forms/source/inc/componenttools.hxx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-10-01 15:32:00 +0200
committerNoel Grandin <noel@peralex.com>2015-10-02 08:20:11 +0200
commitde020fc9c3c67541067bc7e0b72ed41eae650288 (patch)
treeb4f3d4a10ad71c4d2c77b4ef2785de4cde19faaf /forms/source/inc/componenttools.hxx
parentdb494c6b34fa14d5f444f39b52a7cdad90e7f21a (diff)
com::sun::star->css in forms/
Change-Id: I1c09e88f839bdf11c6ff809ec95769e8f729c7cd
Diffstat (limited to 'forms/source/inc/componenttools.hxx')
-rw-r--r--forms/source/inc/componenttools.hxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/forms/source/inc/componenttools.hxx b/forms/source/inc/componenttools.hxx
index 969a442a3126..4a41e88d9938 100644
--- a/forms/source/inc/componenttools.hxx
+++ b/forms/source/inc/componenttools.hxx
@@ -32,10 +32,10 @@ namespace frm
{
- struct TypeCompareLess : public ::std::binary_function< ::com::sun::star::uno::Type, ::com::sun::star::uno::Type, bool >
+ struct TypeCompareLess : public ::std::binary_function< css::uno::Type, css::uno::Type, bool >
{
private:
- typedef ::com::sun::star::uno::Type Type;
+ typedef css::uno::Type Type;
public:
bool operator()( const Type& _rLHS, const Type& _rRHS ) const
@@ -44,14 +44,14 @@ namespace frm
}
};
/** a helper class which merges sequences of <type scope="com::sun::star::uno">Type</type>s,
so that the resulting sequence contains every type at most once
*/
class TypeBag
{
public:
- typedef ::com::sun::star::uno::Type Type;
- typedef ::com::sun::star::uno::Sequence< Type > TypeSequence;
+ typedef css::uno::Type Type;
+ typedef css::uno::Sequence< Type > TypeSequence;
typedef ::std::set< Type, TypeCompareLess > TypeSet;
private:
@@ -81,8 +81,8 @@ namespace frm
TypeSequence getTypes() const;
};
- ::com::sun::star::uno::Reference< ::com::sun::star::frame::XModel > getXModel(
- const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& _rxComponent );
+ css::uno::Reference< css::frame::XModel > getXModel(
+ const css::uno::Reference< css::uno::XInterface >& _rxComponent );
} // namespace frm
@@ -44,14 +44,14 @@ namespace frm
}
};
- /** a helper class which merges sequences of <type scope="com::sun::star::uno">Type</type>s,
+ /** a helper class which merges sequences of <type scope="css::uno">Type</type>s,
so that the resulting sequence contains every type at most once
*/